@@ -531,7 +531,35 @@ int convert_A(char *stago, char *elemname, char **attr, char *tagc)
 		p = p2;
 	    }
 	}
-
+#ifndef ENABLE_UPMAIL
+        // for @Mail
+	strcpy(print_buf, "<a task='gosub' dest='mailto:");
+	p = strchr(print_buf, '\0');
+	if (to) {
+	    sprintf(p, "%s", to);
+	    my_free(to);
+	    p = strchr(print_buf, '\0');
+	}
+	if (subj) {
+	    sprintf(p, "?subject=%s", subj);
+	    my_free(subj);
+	    p = strchr(print_buf, '\0');
+	}
+	if (mt) {
+            if (subj) {
+              strcpy(p, "&amp;");
+              p+=5;
+            } else {
+              strcpy(p, "?");
+              p++;
+            }
+            sprintf(p, "Body=%s", mt);
+	    my_free(mt);
+	    p = strchr(print_buf, '\0');
+	}
+	sprintf(p, "'>");
+#else
+        // for Up.Mail
 	sprintf(print_buf,
 		"<a task='gosub'"
 		" dest='device:home/goto?svc=Email&SUB=sendMsg'"
@@ -554,7 +582,9 @@ int convert_A(char *stago, char *elemname, char **attr, char *tagc)
 	}
 	if (*(p-1) == '&') p--;
 	sprintf(p, "'>");
-		
+#endif
+
+
 /*
 		"<action type='soft1' task='gosub'"
 		" dest='device:home/goto?svc=Email&SUB=sendMsg'"
